#ifndef XPYB_CONSTANT_H
#define XPYB_CONSTANT_H

int xpybConstant_modinit(PyObject *m);

#endif
